@@ -62,7 +62,7 @@ impl_load (PortableServer_Servant servant,
 	int result;
 	
 	if (pf->load_fn != NULL)
-		result = (*pf->load_fn)(pf, filename, pf->closure, ev);
+		result = (*pf->load_fn)(pf, filename, ev, pf->closure);
 	else {
 		GtkObjectClass *oc = GTK_OBJECT (pf)->klass;
 		BonoboPersistFileClass *class = BONOBO_PERSIST_FILE_CLASS (oc);
@@ -86,7 +86,7 @@ impl_save (PortableServer_Servant servant,
 	int result;
 	
 	if (pf->save_fn != NULL)
-		result = (*pf->save_fn)(pf, filename, pf->closure, ev);
+		result = (*pf->save_fn)(pf, filename, ev, pf->closure);
 	else {
 		GtkObjectClass *oc = GTK_OBJECT (pf)->klass;
 		BonoboPersistFileClass *class = BONOBO_PERSIST_FILE_CLASS (oc);
@@ -112,10 +112,10 @@ bonobo_persist_file_get_epv (void)
 
 	epv = g_new0 (POA_Bonobo_PersistFile__epv, 1);
 
-	epv->load		= impl_load;
-	epv->save		= impl_save;
-	epv->is_dirty		= impl_is_dirty;
-	epv->get_current_file   = impl_get_current_file;
+	epv->load           = impl_load;
+	epv->save           = impl_save;
+	epv->isDirty        = impl_is_dirty;
+	epv->getCurrentFile = impl_get_current_file;
 
 	return epv;
 }
