@@ -4,8 +4,8 @@
    All rights reserved.
     
    The Gnome Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   modify it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of the
    License, or (at your option) any later version.
 
    The Gnome Library is distributed in the hope that it will be useful,
@@ -197,6 +197,9 @@ bonobo_ui_toolbar_icon_class_init (BonoboUIToolbarIconClass *class)
         widget_class->size_request = bonobo_ui_toolbar_icon_size_request;
 	object_class->get_arg = bonobo_ui_toolbar_icon_get_arg;
 	object_class->set_arg = bonobo_ui_toolbar_icon_set_arg;
+
+	/* We are going to be using gdk_pixbuf_render_* */
+	gdk_rgb_init ();
 }
 
 static void
