@@ -190,9 +190,8 @@ pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
 	pos = 0;
 	
 	while (pos < bonobo_object_data->sound_len) {
-		CORBA_long bytes_read;
-
-		bytes_read = Bonobo_Stream_write (stream, buffer, ev);
+   
+		Bonobo_Stream_write (stream, buffer, ev);
 
 		if (ev->_major != CORBA_NO_EXCEPTION) {
 			CORBA_free (buffer);
@@ -200,7 +199,7 @@ pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
 			return;
 		}
 
-		pos += bytes_read;
+		pos += buffer->_length;
 	}
 
 	CORBA_free (buffer);
