@@ -370,12 +370,6 @@ create_control_menus (bonobo_object_data_t *bonobo_object_data)
 	bonobo_ui_component_set_tree (bonobo_object_data->uic, "/menu", parent, NULL);
 }
 
-static void
-control_set_frame_cb (BonoboControl *control, gpointer data)
-{
-	create_control_menus ((bonobo_object_data_t *) data);
-}
-
 static void
 control_activate_cb (BonoboControl *control, gboolean activate, gpointer data)
 {
@@ -505,9 +499,8 @@ pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
 
 	pos = 0;
 	while (pos < bonobo_object_data->text_len) {
-		CORBA_long bytes_read;
-
-		bytes_read = Bonobo_Stream_write (stream, buffer, ev);
+		
+		Bonobo_Stream_write (stream, buffer, ev);
 
 		if (ev->_major != CORBA_NO_EXCEPTION) {
 			CORBA_free (buffer);
@@ -515,7 +508,7 @@ pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
 			return;
 		}
 
-		pos += bytes_read;
+		pos += buffer->_length;
 	}
 
 	CORBA_free (buffer);
@@ -690,8 +683,6 @@ generic_factory (BonoboGenericFactory *this, void *data)
 
 	gtk_signal_connect (GTK_OBJECT (bonobo_object), "activate",
 			    GTK_SIGNAL_FUNC (control_activate_cb), bonobo_object_data);
-	gtk_signal_connect (GTK_OBJECT (bonobo_object), "set_frame",
-			    GTK_SIGNAL_FUNC (control_set_frame_cb), bonobo_object_data);
 
 	running_objects++;
 
