@@ -24,48 +24,37 @@
 #include <string.h>
 #include "ib1_driver.h"
 
-static EFSResult  ib1_file_open  (EFSFile **file, EFSDir *dir, 
-				  const char *path, gint flags);
-static EFSResult  ib1_file_close (EFSFile *file);
+static EFSResult  ib1_node_open  (EFSNode **node, EFSDir *dir, 
+				  const char *path, gint flags, gint type);
+static EFSResult  ib1_node_close (EFSNode *node);
 static EFSResult  ib1_file_seek  (EFSFile *file, gint32 offset, gint whence,
 				  guint32 *pos);
+static EFSResult  ib1_dir_seek   (EFSDir *dir, guint32 offset);
 static EFSResult  ib1_file_read  (EFSFile *file, gpointer buf, gint32 count,
 				  gint32 *bytes_read);
+static EFSResult  ib1_dir_read   (EFSDir *dir, EFSDirEntry *de);
 static EFSResult  ib1_file_write (EFSFile *file, gpointer buf, gint32 count);
 static EFSResult  ib1_file_trunc (EFSFile *file, guint32 size);
 static EFSResult  ib1_type_set   (EFSNode *node, guint32 type);
 static EFSResult  ib1_type_get   (EFSNode *node, guint32 *type);
-static EFSResult  ib1_stat       (EFSDir *dir, const char *path,
-				  EFSStat *stat);
+static EFSResult  ib1_node_stat  (EFSNode *node, EFSStat *stat);
 static EFSResult  ib1_erase      (EFSDir *dir, const char *path); 
-
-
-static EFSResult  ib1_dir_open   (EFSDir **dir, EFSDir *parent, 
-				  const char *path, gint flags);
-static EFSResult  ib1_dir_close  (EFSDir *dir);
-static EFSResult  ib1_dir_seek   (EFSDir *dir, guint32 offset);
-static EFSResult  ib1_dir_read   (EFSDir *dir, EFSDirEntry *de);
 static EFSResult  ib1_rename     (EFSDir *dir, const char *old_path, 
 				  const char *new_path);
 
 EFSFileOps file_ops_ib1 = {
-	ib1_file_open,
-	ib1_file_close,
+	ib1_node_open,
+	ib1_node_close,
 	ib1_file_seek,
+	ib1_dir_seek,
 	ib1_file_read,
+	ib1_dir_read,
 	ib1_file_write,
 	ib1_file_trunc,
 	ib1_type_set,
 	ib1_type_get,
-	ib1_stat,
+	ib1_node_stat,
 	ib1_erase,
-};
-
-EFSDirOps dir_ops_ib1 = {
-	ib1_dir_open,
-	ib1_dir_close,
-	ib1_dir_seek,
-	ib1_dir_read,
 	ib1_rename
 };
 
@@ -363,122 +352,89 @@ ib1_namei (IB1EFS *efs, guint32 dir_inode, const char *path,
 }
 
 /*
- * ib1_file_open:
+ * ib1_node_open:
+ *
  *
- * see efs_file_open().
  */
 
 static EFSResult
-ib1_file_open (EFSFile **file, EFSDir *efs_dir, const char *path, gint flags)
+ib1_node_open (EFSNode **node, EFSDir *efs_dir, const char *path, 
+	       gint flags, gint type)
 {
 	IB1CacheEntry *ce;
-	IB1Dir *dir = (IB1Dir *)efs_dir;
+	IB1Dir *parent = (IB1Dir *)efs_dir;
 	IB1EFS *efs = (IB1EFS *)efs_dir->efs;
 	IB1DirEntry *de;
 	guint32 inode;
-
-	if (!(ce = ib1_namei (efs, dir->inode, path, &de, flags, NULL)) || !de)
-		return EFS_ERR_NOENT;
-	
-	if (!de->inode) { /* create a new file */
-		if (!(flags&EFS_CREATE)) return EFS_ERR_NOENT;
-		CLOCK(ce);
-		inode = ib1_inode_create (efs);
-		CUNLOCK(ce);
-		if (!inode) return EFS_ERR_INT;
-		de->inode = GUINT32_TO_LE(inode);
-		de->type = EFS_FILE | (flags&EFS_COMP);
-	} else inode = GUINT32_FROM_LE(de->inode); /* file exists */
-	
-	if (!(de->type&EFS_FILE)) return EFS_ERR_NOTFILE;
-	
-	(IB1File *)(*file) = g_new0 (IB1File, 1);
-	(*file)->efs = (EFS *)efs;
-	(*file)->mode = (flags&(EFS_RDWR|EFS_APPEND))|(de->type&EFS_COMP);
-	((IB1File *)(*file))->inode = inode;
-	ib1_inode_ref (efs, inode);
-	
-	return EFS_ERR_OK;
-}
-
-/*
- * ib1_dir_open:
- *
- * see efs_dir_open().
- */
-
-static EFSResult
-ib1_dir_open (EFSDir **dir, EFSDir *efs_parent, const char *path, gint flags)
-{
-	IB1CacheEntry *ce;
-	IB1Dir *parent = (IB1Dir *)efs_parent;
-	IB1EFS *efs = (IB1EFS *)efs_parent->efs;
-	IB1DirEntry *de;
-	guint32 inode;
 	const gchar *p;
 
+	if ((flags&EFS_CREATE) && !type) return EFS_ERR_INVAL;
+
 	p = path; while ((*p) == '/') p++;
 
-	if (!(*p)) { /* dup */
-		(IB1Dir *)(*dir) = g_new0 (IB1Dir, 1);
-		*((IB1Dir *)(*dir)) = *((IB1Dir *)efs_parent);
-		ib1_inode_ref (efs, ((IB1Dir *)(*dir))->inode);
-		(*dir)->mode &= ~(EFS_ROOT);
+	type = type & (EFS_FILE|EFS_DIR);
+
+	if (!(*p)) { /* dup directory*/
+		if (type == EFS_FILE) return EFS_ERR_NOTFILE; 
+		(IB1Dir *)(*node) = g_new0 (IB1Dir, 1);
+		*((IB1Dir *)(*node)) = *((IB1Dir *)parent);
+		ib1_inode_ref (efs, ((IB1Dir *)(*node))->inode);
+		(*node)->mode &= ~(EFS_ROOT);
 		return EFS_ERR_OK;
 	}
 
-	if (!(ce=ib1_namei (efs, parent->inode, p, &de, flags, NULL)) || !de) 
+	if (!(ce = ib1_namei (efs, parent->inode, p, &de, flags, NULL)) || !de)
 		return EFS_ERR_NOENT;
-
-	if (!de->inode) { /* create a new directory */
+	
+	if (!de->inode) { /* create a new file or directory*/
 		if (!(flags&EFS_CREATE)) return EFS_ERR_NOENT;
 		CLOCK(ce);
 		inode = ib1_inode_create (efs);
 		CUNLOCK(ce);
 		if (!inode) return EFS_ERR_INT;
 		de->inode = GUINT32_TO_LE(inode);
-		de->type = EFS_DIR;
-	} else inode = GUINT32_FROM_LE(de->inode);  /* directory exists */
-       
-	if (de->type != EFS_DIR) return EFS_ERR_NOTDIR;
+		de->type = type | (flags&EFS_COMP);
+	} else inode = GUINT32_FROM_LE(de->inode); /* file/dir exists */
 	
-	(IB1Dir *)(*dir) = g_new0 (IB1Dir, 1);
-	(*dir)->efs = (EFS *)efs;
-	((IB1Dir *)(*dir))->inode = inode;
-	ib1_inode_ref (efs, inode);
+	if (de->type & EFS_FILE) {
+		if (!(de->type & EFS_FILE)) return EFS_ERR_NOTFILE;
+		(IB1File *)(*node) = g_new0 (IB1File, 1);
+		(*node)->efs = (EFS *)efs;
+		(*node)->mode = (flags&(EFS_RDWR|EFS_APPEND)) | EFS_FILE | 
+			(de->type&EFS_COMP);
+		((IB1File *)(*node))->inode = inode;
+		ib1_inode_ref (efs, inode);
+	}
+
+	if (de->type & EFS_DIR) {
+		if (!(de->type & EFS_DIR)) return EFS_ERR_NOTDIR;
+		(IB1Dir *)(*node) = g_new0 (IB1Dir, 1);
+		(*node)->efs = (EFS *)efs; 
+		(*node)->mode = EFS_DIR;
+		((IB1Dir *)(*node))->inode = inode;
+		ib1_inode_ref (efs, inode);
+	}
 	
 	return EFS_ERR_OK;
 }
 
 /*
- * ib1_file_close:
+ * ib1_node_close:
  *
- * see efs_file_close().
+ * 
  */
 
 static EFSResult
-ib1_file_close (EFSFile *efs_file)
+ib1_node_close (EFSNode *node)
 {
-	IB1File *file = (IB1File *)efs_file;
-	IB1EFS *efs = (IB1EFS *)efs_file->efs;
+	IB1File *file = (IB1File *)node;
+	IB1EFS *efs = (IB1EFS *)node->efs;
 
 	ib1_inode_unref (efs, file->inode);
 
 	return EFS_ERR_OK;
 }
 
-/*
- * ib1_dir_close:
- *
- * see efs_dir_close().
- */
-
-static EFSResult
-ib1_dir_close (EFSDir *efs_dir)
-{
-	return ib1_file_close (efs_dir);;
-}
-
 /*
  * ib1_file_seek:
  *
@@ -747,6 +703,11 @@ ib1_file_trunc (EFSFile *efs_file, guint32 size)
 	return EFS_ERR_OK;
 }
 
+/*
+ * ib1_type_set:
+ *
+ */
+
 static EFSResult
 ib1_type_set (EFSNode *efs_node, guint32 type)
 {
@@ -759,10 +720,15 @@ ib1_type_set (EFSNode *efs_node, guint32 type)
 	node = NODEP(ce, file->inode);
 	node->type = GINT32_TO_LE(type);
 	ib1_cache_touch (ce, TRUE);
-	
+
 	return EFS_ERR_OK;
 }
 
+/*
+ * ib1_type_get:
+ *
+ */
+
 static EFSResult
 ib1_type_get (EFSFile *efs_node, guint32 *type)
 {
@@ -780,27 +746,22 @@ ib1_type_get (EFSFile *efs_node, guint32 *type)
 }
 
 /*
- * ib1_stat:
+ * ib1_node_stat:
  *
- * see efs_stat().
  */
 
 static EFSResult
-ib1_stat (EFSDir *efs_dir, const char *path, EFSStat *stat)
+ib1_node_stat (EFSNode *efs_node, EFSStat *stat)
 {
-	IB1Dir *dir = (IB1Dir *)efs_dir;
-	IB1EFS *efs = (IB1EFS *)efs_dir->efs;
+	IB1EFS *efs = (IB1EFS *)efs_node->efs;
 	IB1CacheEntry *ce;
-	IB1DirEntry *de;
 	IB1INode *node;
+	guint32 inode = ((IB1File *)efs_node)->inode;
 
-	if (!(ce = ib1_namei (efs, dir->inode, path, &de, 0, NULL)) || !de)
-		return EFS_ERR_NOENT;
+	stat->type = efs_node->mode & (EFS_DIR|EFS_FILE);
 
-	stat->type = de->type & (EFS_DIR|EFS_FILE);
-
-	if (!(ce = ib1_inode_map (efs, de->inode, FALSE))) return EFS_ERR_INT;
-	node = NODEP(ce, de->inode);
+	if (!(ce = ib1_inode_map (efs, inode, FALSE))) return EFS_ERR_INT;
+	node = NODEP(ce, inode);
 	
 	stat->size = GUINT32_FROM_LE (node->size);
 
